@@ -2,9 +2,9 @@
 {-# LANGUAGE ScopedTypeVariables #-}
 {-|
 Module      : Test.Tasty.Lua.Core
-Copyright   : © 2019–2022 Albert Krewinkel
+Copyright   : © 2019-2023 Albert Krewinkel
 License     : MIT
-Maintainer  : Albert Krewinkel <albert+hslua@zeitkraut.de>
+Maintainer  : Albert Krewinkel <tarleb@hslua.org>
 
 Core types and functions for tasty Lua tests.
 -}
@@ -17,10 +17,10 @@ module Test.Tasty.Lua.Core
 where
 
 import Control.Monad ((<$!>), void)
-import HsLua.Core (LuaE, LuaError, toboolean, top)
+import HsLua.Core (LuaE, LuaError, pop, toboolean, top)
 import HsLua.Marshalling
-  ( Peeker, failPeek, liftLua, resultToEither, retrieving
-  , peekFieldRaw, peekList, peekString, runPeek, typeMismatchMessage)
+  ( Peeker, lastly, liftLua, resultToEither, retrieving
+  , peekFieldRaw, peekList, peekString, runPeek)
 import Test.Tasty.Lua.Module (pushModule)
 import qualified HsLua.Core as Lua
 import qualified HsLua.Core.Utf8 as Utf8
@@ -32,7 +32,7 @@ runTastyFile :: LuaError e => FilePath -> LuaE e (Either String [ResultTree])
 runTastyFile fp = do
   Lua.openlibs
   Lua.requirehs "tasty" (const . void $ pushModule)
-  res <- Lua.dofileTrace fp
+  res <- Lua.dofileTrace (Just fp)
   if res /= Lua.OK
     then Left . Utf8.toString <$> Lua.tostring' top
     else resultToEither <$> runPeek (peekList peekResultTree top)
@@ -64,11 +64,12 @@ peekUnnamedTree idx = liftLua (Lua.ltype idx) >>= \case
 data Outcome = Success | Failure String
 
 -- | Unmarshal a test outcome
-peekOutcome :: Peeker e Outcome
+peekOutcome :: LuaError e => Peeker e Outcome
 peekOutcome idx = retrieving "test result" $ do
   liftLua (Lua.ltype idx) >>= \case
     Lua.TypeString  -> Failure <$!> peekString idx
     Lua.TypeBoolean -> do
       b <- liftLua $ toboolean idx
       return $ if b then Success else Failure "???"
-    _ -> typeMismatchMessage "string or boolean" idx >>= failPeek
+    _ -> Failure <$!>
+         (liftLua (Lua.tostring' idx) *> peekString top) `lastly` pop 1
