@@ -1,8 +1,8 @@
 {-|
 Module      : Test.Tasty.Lua.Translate
-Copyright   : © 2019–2022 Albert Krewinkel
+Copyright   : © 2019-2023 Albert Krewinkel
 License     : MIT
-Maintainer  : Albert Krewinkel <albert+hslua@zeitkraut.de>
+Maintainer  : Albert Krewinkel <tarleb@hslua.org>
 
 Translate test results from Lua into a Tasty @'TestTree'@.
 -}
